<?php
#####################################################################################################
#
#					Module pour la plateforme de paiement PayZen
#						Version : 2.7a (rvision 49136)
#									########################
#					Dvelopp pour osCommerce
#						Version : 2.2ms2
#						Compatibilit plateforme : V2
#									########################
#					Dvelopp par Lyra Network
#						http://www.lyra-network.com/
#						04/07/2013
#						Contact : support@payzen.eu
#
#####################################################################################################

/**
 * Main class implementing PayZen payment module for OSC.
 */
class payzen {
	/**
	 * @var string
	 */
	var $code;
	/**
	 * @var string
	 */
	var $title;
	/**
	 * @var string
	 */
	var $description;
	/**
	 * @var boolean
	 */
	var $enabled;
	/**
	 * @var int
	 */
	var $sort_order;
	/**
	 * @var string
	 */
	var $form_action_url;
	/**
	 * @var int
	 */
	var $order_status;

	/**
	 * Class constructor
	 */
	function payzen() {
		global $order;

		// initialize code
		$this->code = 'payzen';
		
		// initialize title
		$this->title = MODULE_PAYMENT_PAYZEN_TITLE;
		
		// initialize description
		$this->description  = '';
		$this->description .= '<b>' . MODULE_PAYMENT_PAYZEN_MODULE_INFORMATION . '</b>';
		$this->description .= '<br/><br/>';
		
		$this->description .= '<table class="infoBoxContent">';
		$this->description .= '<tr><td style="text-align: right;">' . MODULE_PAYMENT_PAYZEN_DEVELOPED_BY . '</td><td><a href="http://www.lyra-network.com/" target="_blank"><b>Lyra network</b></a></td></tr>';
		$this->description .= '<tr><td style="text-align: right;">' . MODULE_PAYMENT_PAYZEN_CONTACT_EMAIL . '</td><td><a href="mailto:support@payzen.eu"><b>support@payzen.eu</b></a></td></tr>';
		$this->description .= '<tr><td style="text-align: right;">' . MODULE_PAYMENT_PAYZEN_CONTRIB_VERSION . '</td><td><b>2.7a</b></td></tr>';
		$this->description .= '<tr><td style="text-align: right;">' . MODULE_PAYMENT_PAYZEN_GATEWAY_VERSION . '</td><td><b>V2</b></td></tr>';
		$this->description .= '<tr><td style="text-align: right;">' . MODULE_PAYMENT_PAYZEN_CMS_VERSION . '</td><td><b>osCommerce 2.2ms2</b></td></tr>';
		$this->description .= '</table>';
		
		$this->description .= '<br/>';
		$this->description .= MODULE_PAYMENT_PAYZEN_CHECK_URL . '<b>' . HTTP_SERVER . DIR_WS_CATALOG . 'checkout_process_payzen.php</b>';
		$this->description .= '<hr />';
		
		// initialize enabled
		$this->enabled = (MODULE_PAYMENT_PAYZEN_STATUS == '1');

		// initialize sort_order
		$this->sort_order = MODULE_PAYMENT_PAYZEN_SORT_ORDER;
		
		$this->form_action_url = MODULE_PAYMENT_PAYZEN_PLATFORM_URL;
		
		if ((int)MODULE_PAYMENT_PAYZEN_ORDER_STATUS > 0) {
			$this->order_status = MODULE_PAYMENT_PAYZEN_ORDER_STATUS;
		}

		// if there's an order to treat, start preliminary payment zone check
		if (is_object($order)) {
			$this->update_status();
		}
	}

	/**
	 * Payment zone and amount restriction checks
	 */
	function update_status() {
		global $order;
		
		if(!$this->enabled) {
			return;
		}

		// check customer zone
		if ((int)MODULE_PAYMENT_PAYZEN_ZONE > 0) {
			$flag = false;
			$check_query = tep_db_query("SELECT zone_id FROM " . TABLE_ZONES_TO_GEO_ZONES .
										" WHERE geo_zone_id = '" . MODULE_PAYMENT_PAYZEN_ZONE .
										"' AND zone_country_id = '" . $order->billing['country']['id'] .
										"' ORDER by zone_id ASC;");
			while ($check = tep_db_fetch_array($check_query)) {
				if (($check['zone_id'] < 1) || ($check['zone_id'] == $order->billing['zone_id'])) {
					$flag = true;
					break;
				}
			}

			if (!$flag) {
				$this->enabled = false;
			}	
		}
		
		// check amount restrictions
		if ((MODULE_PAYMENT_PAYZEN_AMOUNT_MIN != '' && $order->info['total'] < MODULE_PAYMENT_PAYZEN_AMOUNT_MIN)
				|| (MODULE_PAYMENT_PAYZEN_AMOUNT_MAX != '' && $order->info['total'] > MODULE_PAYMENT_PAYZEN_AMOUNT_MAX)) {
			$this->enabled = false;
		}
		
		// check currency		
		require_once(DIR_FS_CATALOG . 'includes/classes/payzen_api.php'); // load PayZen payment API
		$payzenApi = new PayzenApi('ISO-8859-1');
		
		$defaultCurrency = (defined('USE_DEFAULT_LANGUAGE_CURRENCY') && USE_DEFAULT_LANGUAGE_CURRENCY == 'true') ? LANGUAGE_CURRENCY : DEFAULT_CURRENCY;
		if(!$payzenApi->findCurrencyByAlphaCode($order->info['currency']) && $payzenApi->findCurrencyByAlphaCode($defaultCurrency)) {
			// currency is not supported, module is not available
			$this->enabled = false;
		}
	}

	/**
	 * JS checks : we let the platform do all the validation itself
	 * @return false
	 */
	function javascript_validation() {
		return false;
	}

	/**
	 * Parameters for what the payment option will look like in the list
	 * @return array
	 */
	function selection() {
		return array(
				'id' => $this->code,
                'module' => $this->title
		);
	}

	/**
	 * Server-side checks after payment selection : We let the platform do all the validation itself
	 * @return false
	 */
	function pre_confirmation_check() {
		return false;
	}

	/**
	 * Server-size checks before payment confirmation :  We let the platform do all the validation itself
	 * @return false
	 */
	function confirmation() {
		return false;
	}

	/**
	 * Prepare the form that will be sent to the payment gateway
	 * @return string
	 */
	function process_button() {
		global $order, $languages_id, $currencies, $customer_id;
		
		// load PayZen payment API
		require_once(DIR_FS_CATALOG . 'includes/classes/payzen_api.php'); 
		$payzenApi = new PayzenApi('ISO-8859-1');
		
		// admin configuration parameters
		$configParams = array(
				'site_id', 'key_test', 'key_prod', 'ctx_mode', 'platform_url', 'available_languages',
				'capture_delay', 'validation_mode', 'payment_cards', 'redirect_enabled',
				'redirect_success_timeout', 'redirect_success_message', 'redirect_error_timeout',
				'redirect_error_message', 'return_mode'
		);
		
		foreach ($configParams as $name) {
			$payzenApi->set($name, constant('MODULE_PAYMENT_PAYZEN_' . strtoupper($name)));
		}
		
		// get the shop language code
		$query = tep_db_query("SELECT code FROM " . TABLE_LANGUAGES . " WHERE languages_id = " . $languages_id);
		$langData = tep_db_fetch_array($query);
		$language = $payzenApi->isSupportedLanguage($langData['code']) ?
					strtolower($langData['code']) :
					MODULE_PAYMENT_PAYZEN_LANGUAGE;
		
		// get the currency to use
		$currencyValue = $order->info['currency_value'];
		$payzenCurrency = $payzenApi->findCurrencyByAlphaCode($order->info['currency']);
		if(!$payzenCurrency) {
			// currency is not supported, use the default shop currency
			$defaultCurrency = (defined('USE_DEFAULT_LANGUAGE_CURRENCY') && USE_DEFAULT_LANGUAGE_CURRENCY == 'true') ? 
								LANGUAGE_CURRENCY : DEFAULT_CURRENCY;
			
			$payzenCurrency = $payzenApi->findCurrencyByAlphaCode($defaultCurrency);
			$currencyValue = 1;
		}
		
		// calculate amount ...
		$total = tep_round($order->info['total'] * $currencyValue, $currencies->get_decimal_places($payzenCurrency->alpha3));
		
		// activate 3ds ?
		$threedsMpi = null;
		if(MODULE_PAYMENT_PAYZEN_3DS_MIN_AMOUNT != '' && $order->info['total'] < MODULE_PAYMENT_PAYZEN_3DS_MIN_AMOUNT) {
			$threedsMpi = '2';
		}
		
		// other parameters
		$data = array(
				// order info
				'amount' => $payzenCurrency->convertAmountToInteger($total),
				'order_id' => $this->_guess_order_id(),
				'contrib' => 'osCommerce2.2ms2_2.7a/' . PROJECT_VERSION,
				'order_info' => 'session_id=' . session_id(),
		
				// misc data 
				'currency' => $payzenCurrency->num, 
				'language' => $language,
				'threeds_mpi' => $threedsMpi,
				'url_return' => tep_href_link(FILENAME_CHECKOUT_PROCESS, '', 'SSL'),
				
				// customer info
				'cust_id' => $customer_id,
				'cust_email' => $order->customer['email_address'],
				'cust_phone' => $order->customer['telephone'],
				'cust_first_name' => $order->billing['firstname'],
				'cust_last_name' => $order->billing['lastname'],
				'cust_address' => $order->billing['street_address'] . ' ' . $order->billing['suburb'],
				'cust_city' => $order->billing['city'],
				'cust_state' => $order->billing['state'],
				'cust_zip' => $order->billing['postcode'],
				'cust_country' => $order->billing['country']['iso_code_2']
		);
		
		// delivery data
		if($order->delivery != false) {
			$data['ship_to_first_name'] = $order->delivery['firstname'];
			$data['ship_to_last_name'] = $order->delivery['lastname'];
			$data['ship_to_street'] = $order->delivery['street_address'];
			$data['ship_to_street2'] = $order->delivery['suburb'];
			$data['ship_to_city'] = $order->delivery['city'];
			$data['ship_to_state'] = $order->delivery['state'];
			
			$countryCode = $order->delivery['country']['iso_code_2'];
			if($countryCode == 'FX') { // FX not recognized as a country code by PayPal
				$countryCode = 'FR';
			}
			$data['ship_to_country'] = $countryCode;
			
			//$data['ship_to_country'] = $order->delivery['country']['iso_code_2'];
			$data['ship_to_zip'] = $order->delivery['postcode'];
		}
		
		$payzenApi->setFromArray($data);
		
		return $payzenApi->getRequestFieldsHtml();
	}

	/**
	 * Verify client data after he returned from payment gateway
	 */
	function before_process() { 
		global $order, $language, $payzenResponse;
		
		// load PayZen payment API
		require_once(DIR_FS_CATALOG . 'includes/classes/payzen_api.php');
		require_once(DIR_FS_CATALOG . "includes/languages/$language/modules/payment/payzen.php");
		
		$payzenResponse = new PayzenResponse(
				$_REQUEST,
				MODULE_PAYMENT_PAYZEN_CTX_MODE,
				MODULE_PAYMENT_PAYZEN_KEY_TEST,
				MODULE_PAYMENT_PAYZEN_KEY_PROD
		);
		$fromServer = $payzenResponse->get('hash');
		
		// Check authenticity
		if(!$payzenResponse->isAuthentified()) {
			if($fromServer) {
				die($payzenResponse->getOutputForGateway('auth_fail'));
			} else {
				tep_redirect(
						tep_href_link(FILENAME_CHECKOUT_PAYMENT, 'error_message=' . urlencode(MODULE_PAYMENT_PAYZEN_TECHNICAL_ERROR), 'NONSSL', true)
				);
		
				die();
			}
		}
		
		// messages to display on payment result page
		$params = '';
		if(MODULE_PAYMENT_PAYZEN_CTX_MODE == 'TEST') {
			$params .= 'info_message=' . urlencode(MODULE_PAYMENT_PAYZEN_GOING_INTO_PROD_INFO);
		}
		
		// act according to case
		if($payzenResponse->isAcceptedPayment()) {
			// successful payment
		
			if($this->_is_order_paid()) {
				if($fromServer) {
					die ($payzenResponse->getOutputForGateway('payment_ok_already_done'));
				} else {
					$this->_clear_session_vars();
					tep_redirect(tep_href_link(FILENAME_CHECKOUT_SUCCESS, $params, 'SSL', true));
					die();
				}
			} else {
				// update order payment data
				$order->info['cc_type'] = $payzenResponse->get('card_brand');
				$order->info['cc_number'] = $payzenResponse->get('card_number');
				$order->info['cc_expires'] = str_pad($payzenResponse->get('expiry_month'), 2, '0', STR_PAD_LEFT) . substr($payzenResponse->get('expiry_year'), 2);
				
				// use payment method short name to avoid truncate
				$order->info['payment_method'] = MODULE_PAYMENT_PAYZEN_SHORT_TITLE;
				
				// let's borrow the cc_owner field to store transaction id
				$order->info['cc_owner'] = '-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Transaction: ' . $payzenResponse->get('trans_id');
				
				// Let checkout_process.php finish the job
				return false;
			}
			
		} else {
			// payment process failed
			if($fromServer) {
				die($payzenResponse->getOutputForGateway('payment_ko'));
			} else {
				$params  .= '&error_message=' . urlencode(MODULE_PAYMENT_PAYZEN_PAYMENT_ERROR);
				tep_redirect(tep_href_link(FILENAME_CHECKOUT_PAYMENT, $params, 'NONSSL'));
				die();
			}
		}
	}

	/**
	 * Post-processing after the order has been finalised
	 */
	function after_process() {
		global $cart, $payzenResponse;
		
		// this function is called only when payment was successful and the order is not registered yet
		
		$fromServer = $payzenResponse->get('hash');
		
		// reset cart to allow new checkout process
		$cart->reset(true);
		
		if($fromServer) {
			die ($payzenResponse->getOutputForGateway('payment_ok'));
		} else {
			$this->_clear_session_vars();
			
			// payment confirmed by client retun, show a warning if TEST mode
			if(MODULE_PAYMENT_PAYZEN_CTX_MODE == 'TEST') {
				$params = 'info_message=' . urlencode(MODULE_PAYMENT_PAYZEN_GOING_INTO_PROD_INFO);
				$params .= '&error_message=' . urlencode(MODULE_PAYMENT_PAYZEN_CHECK_URL_WARN);
				$params .= ' ' . urlencode(MODULE_PAYMENT_PAYZEN_CHECK_URL_WARN_DETAIL);
			}
		
			tep_redirect(tep_href_link(FILENAME_CHECKOUT_SUCCESS, $params, 'SSL'));
		
			require(DIR_WS_INCLUDES . 'application_bottom.php');
			
			die();
		}
	}
	
	// unregister session variables used during checkout
	function _clear_session_vars() {
		tep_session_unregister('sendto');
		tep_session_unregister('billto');
		tep_session_unregister('shipping');
		tep_session_unregister('payment');
		tep_session_unregister('comments');
	}

	/**
	 * Return true / 1 if the module is installed
	 * @return unknown_type
	 */
	function check() {
		if (!isset($this->_check)) {
			$check_query = tep_db_query("SELECT configuration_value FROM " . TABLE_CONFIGURATION .
										" WHERE configuration_key = 'MODULE_PAYMENT_PAYZEN_STATUS'");
			$this->_check = tep_db_num_rows($check_query);
		}
		return $this->_check;
	}
	
	
	/**
	 * Build and execute a query for the install() function
	 * Parameters have to be escaped before
	 *
	 * @param string $title
	 * @param string $key
	 * @param string $value
	 * @param string $description
	 * @param string $group_id
	 * @param string $sort_order
	 * @param string $date_added
	 * @param string $set_function
	 * @param string $use_function
	 * @return
	 */
	function _install_query($key, $value, $group_id, $sort_order, $set_function=null, $use_function=null) {
		// Get title and desc translations
		$title = constant($key.'_TITLE');
		$description = constant($key.'_DESC');
		// Build query
		$query  = "";
		$query .= "INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added";
		$query .= isset($set_function) ? ", set_function" : "";
		$query .= isset($use_function) ? ", use_function" : "";
		$query .= ") VALUES (";
		$query .= "'".mysql_real_escape_string($title)."'";
		$query .= ", '".$key."'";
		$query .= ", '".$value."'";
		$query .= ", '".mysql_real_escape_string($description)."'";
		$query .= ", '".$group_id."'";
		$query .= ", '".$sort_order."'";
		$query .= ", NOW()";
		$query .= isset($set_function) ? ", '".$set_function."'" : "";
		$query .= isset($use_function) ? ", '".$use_function."'" : "";
		$query .= ");";
		// execute;
		tep_db_query($query);
	}
	
	/**
	 * Module install (register admin-managed parameters in database)
	 */
	function install() {
		global $language;

		// load PayZen payment API and module language file
		require_once(DIR_FS_CATALOG . 'includes/classes/payzen_api.php');
		require_once(DIR_FS_CATALOG . "includes/languages/$language/modules/payment/payzen.php");
		
		// Ex: _install_query($key, $value, $group_id, $sort_order, $set_function=null, $use_function=null)
		// osCommerce specific parameters
		$this->_install_query('MODULE_PAYMENT_PAYZEN_STATUS', '1', 6, 1, 'payzen_cfg_draw_pull_down_bools(', 'payzen_get_bool_title');
		$this->_install_query('MODULE_PAYMENT_PAYZEN_SORT_ORDER', '0', 6, 2);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_ZONE', '0', 6, 3, 'tep_cfg_pull_down_zone_classes(', 'tep_get_zone_class_title');
		
		// gateway access parameters
		$this->_install_query('MODULE_PAYMENT_PAYZEN_SITE_ID', '12345678', 6, 10);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_KEY_TEST', '1111111111111111', 6, 11);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_KEY_PROD', '2222222222222222', 6, 12);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_CTX_MODE', 'TEST', 6, 13, "tep_cfg_select_option(array(\'TEST\', \'PRODUCTION\'),");
		$this->_install_query('MODULE_PAYMENT_PAYZEN_PLATFORM_URL', 'https://secure.payzen.eu/vads-payment/', 6, 14);
		
		$this->_install_query('MODULE_PAYMENT_PAYZEN_LANGUAGE', 'fr', 6, 21, 'payzen_cfg_draw_pull_down_langs(', 'payzen_get_lang_title');
		$this->_install_query('MODULE_PAYMENT_PAYZEN_AVAILABLE_LANGUAGES', '', 6, 22, 'payzen_cfg_draw_pull_down_multi_langs(', 'payzen_get_multi_lang_title');
		$this->_install_query('MODULE_PAYMENT_PAYZEN_CAPTURE_DELAY', '', 6, 23);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_VALIDATION_MODE', '', 6, 24, 'payzen_cfg_draw_pull_down_validation_modes(', 'payzen_get_validation_mode_title');
		$this->_install_query('MODULE_PAYMENT_PAYZEN_PAYMENT_CARDS', '', 6, 25, 'payzen_cfg_draw_pull_down_cards(', 'payzen_get_card_title');
		$this->_install_query('MODULE_PAYMENT_PAYZEN_3DS_MIN_AMOUNT', '', 6, 26);
		
		// amount restriction
		$this->_install_query('MODULE_PAYMENT_PAYZEN_AMOUNT_MIN', '', 6, 30);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_AMOUNT_MAX', '', 6, 31);
			
		// gateway return parameters
		$this->_install_query('MODULE_PAYMENT_PAYZEN_REDIRECT_ENABLED', '0', 6, 40, 'payzen_cfg_draw_pull_down_bools(', 'payzen_get_bool_title');
		$this->_install_query('MODULE_PAYMENT_PAYZEN_REDIRECT_SUCCESS_TIMEOUT', 5, 6, 41);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_REDIRECT_SUCCESS_MESSAGE', 'Redirection vers la boutique dans quelques instants...', 6, 42);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_REDIRECT_ERROR_TIMEOUT', 5, 6, 43);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_REDIRECT_ERROR_MESSAGE', 'Redirection vers la boutique dans quelques instants...', 6, 44);
		$this->_install_query('MODULE_PAYMENT_PAYZEN_RETURN_MODE', 'GET', 6, 45, "tep_cfg_select_option(array(\'GET\', \'POST\'), ");
		$this->_install_query('MODULE_PAYMENT_PAYZEN_ORDER_STATUS', '0', 6, 48, 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name');
	}

	/**
	 * Module deletion
	 */
	function remove() {
		$keys = $this->keys();
		
		foreach($keys as $key) {
			tep_db_query("DELETE FROM " . TABLE_CONFIGURATION . " WHERE configuration_key = '$key'");
		}
	}

	/**
	 * Returns the names of module's parameters
	 * @return array[int]string
	 */
	function keys() {
		return array(
				'MODULE_PAYMENT_PAYZEN_STATUS', 
				'MODULE_PAYMENT_PAYZEN_SORT_ORDER',
				'MODULE_PAYMENT_PAYZEN_ZONE',
			
				'MODULE_PAYMENT_PAYZEN_SITE_ID',
				'MODULE_PAYMENT_PAYZEN_KEY_TEST', 
				'MODULE_PAYMENT_PAYZEN_KEY_PROD',
				'MODULE_PAYMENT_PAYZEN_CTX_MODE', 
				'MODULE_PAYMENT_PAYZEN_PLATFORM_URL',
			
				'MODULE_PAYMENT_PAYZEN_LANGUAGE',
				'MODULE_PAYMENT_PAYZEN_AVAILABLE_LANGUAGES',
				'MODULE_PAYMENT_PAYZEN_CAPTURE_DELAY',
				'MODULE_PAYMENT_PAYZEN_VALIDATION_MODE',
				'MODULE_PAYMENT_PAYZEN_PAYMENT_CARDS',
				'MODULE_PAYMENT_PAYZEN_3DS_MIN_AMOUNT',
				
				'MODULE_PAYMENT_PAYZEN_AMOUNT_MIN',
				'MODULE_PAYMENT_PAYZEN_AMOUNT_MAX',
				
				'MODULE_PAYMENT_PAYZEN_REDIRECT_ENABLED',
				'MODULE_PAYMENT_PAYZEN_REDIRECT_SUCCESS_TIMEOUT',
				'MODULE_PAYMENT_PAYZEN_REDIRECT_SUCCESS_MESSAGE',
				'MODULE_PAYMENT_PAYZEN_REDIRECT_ERROR_TIMEOUT',
				'MODULE_PAYMENT_PAYZEN_REDIRECT_ERROR_MESSAGE',
				'MODULE_PAYMENT_PAYZEN_RETURN_MODE',
				'MODULE_PAYMENT_PAYZEN_ORDER_STATUS'
		);
	}

	/**
	 * Try to guess what will be the order's id when osCommerce will register it at the end of the payment process.
	 * This is only used to set order_id in the request to the payment gateway. It might be inconsistent with the
	 * final osCommerce order id (in cases like two clients going to the payment gateway at the same time...)
	 * 
	 * @return int
	 */
	function _guess_order_id() {
		$sql = "SELECT MAX(orders_id) FROM " . TABLE_ORDERS;

		$res = tep_db_query($sql);

		if(tep_db_num_rows($res) == 0) {
			return 0;
		} else {
			return mysql_result($res, 0, 0) + 1;
		}
	}
	
	/**
	 * Test if order corresponding to entered trans_id is already saved.
	 *
	 * @return boolean true if order already saved
	 */
	function _is_order_paid() {
		global $payzenResponse;
		
		$orderId = $payzenResponse->get('order_id');
		$customerId = $payzenResponse->get('cust_id');
		$transId = $payzenResponse->get('trans_id');
		
		$query = tep_db_query("SELECT * FROM " . TABLE_ORDERS .
				" WHERE orders_id >= $orderId" .
				" AND customers_id = $customerId" . 
				" AND cc_owner LIKE '%Transaction: " . $transId . "'"); 
	
		return tep_db_num_rows($query) > 0;
	}
}


/**
 * General functions to draw PayZen configuration parameters.
 * */ 

global $payzen_supported_languages, $payzen_supported_cards;

// load PayZen payment API
require_once(DIR_FS_CATALOG . 'includes/classes/payzen_api.php');
$payzenApi = new PayzenApi('ISO-8859-1');

$payzen_supported_languages = $payzenApi->getSupportedLanguages();
$payzen_supported_cards = $payzenApi->getSupportedCardTypes();


function payzen_get_bool_title($value) {
	$key = 'MODULE_PAYMENT_PAYZEN_VALUE_' . $value;
	
	if(defined($key)) {
		return constant($key);
	} else {
		return $value;
	}	
}

function payzen_get_lang_title($value) {
	global $payzen_supported_languages;
	
	$key = 'MODULE_PAYMENT_PAYZEN_LANGUAGE_' . strtoupper($payzen_supported_languages[$value]);
	
	if(defined($key)) {
		return constant($key);
	} else {
		return $value;
	}
}

function payzen_get_multi_lang_title($value) {
	if(!empty($value)) {
		$langs = explode(';', $value);
		
		$result = array();
		foreach ($langs as $lang) {
			$result[] = payzen_get_lang_title($lang);
		}
		
		return implode(', ', $result);
	} else {
		return '';
	}
}

function payzen_get_validation_mode_title($value) {
	$key = 'MODULE_PAYMENT_PAYZEN_VALIDATION_' . $value;
	
	if(defined($key)) {
		return constant($key);
	} else {
		return MODULE_PAYMENT_PAYZEN_VALIDATION_DEFAULT;
	}
}

function payzen_get_card_title($value) {
	global $payzen_supported_cards;
	
	if(!empty($value)) {
		$cards = explode(';', $value);
	
		$result = array();
		foreach ($cards as $card) {
			$result[] = $payzen_supported_cards[$card];
		}
	
		return implode(', ', $result);
	} else {
		return '';
	}
}

function payzen_cfg_draw_pull_down_bools($value='', $name) {
	$name = 'configuration[' . tep_output_string($name) . ']';
	if (empty($value) && isset($GLOBALS[$name])) $value = stripslashes($GLOBALS[$name]);
	
	$bools = array('1', '0');
	
	$field = '';
	foreach ($bools as $bool) {
		$field .= '<input type="radio" name="' . $name . '" value="' . $bool . '"';
		if ($value == $bool) {
			$field .= ' checked="checked"';
		}
		
		$field .= '> ' . tep_output_string(payzen_get_bool_title($bool)) . '<br />';
	}
	
	return $field;
}

function payzen_cfg_draw_pull_down_validation_modes($value='', $name) {
	$name = 'configuration[' . tep_output_string($name) . ']';
	
	if (empty($value) && isset($GLOBALS[$name])) $value = stripslashes($GLOBALS[$name]);
	$modes = array('', '0', '1');
	
	$field = '<select name="' . $name . '">';
	foreach ($modes as $mode) {
		$field .= '<option value="' . $mode . '"';
		if ($value == $mode) {
			$field .= ' selected="selected"';
		}
		
		$field .= '>' . tep_output_string(payzen_get_validation_mode_title($mode)) . '</option>';
	}

	$field .= '</select>';

	return $field;
}

function payzen_cfg_draw_pull_down_langs($value='', $name) {
	global $payzen_supported_languages;
	
	$name = 'configuration[' . tep_output_string($name) . ']';
	if (empty($value) && isset($GLOBALS[$name])) $value = stripslashes($GLOBALS[$name]);
	
	$field = '<select name="' . $name . '">';
	foreach ($payzen_supported_languages as $key => $label) {
		$field .= '<option value="' . $key . '"';
		if ($value == $key) {
			$field .= ' selected="selected"';
		}
	
		$field .= '>' . tep_output_string(payzen_get_lang_title($key)) . '</option>';
	}
	
	$field .= '</select>';
	
	return $field;
}

function payzen_cfg_draw_pull_down_multi_langs($value='', $name) {
	global $payzen_supported_languages;
	
	$fieldName = 'configuration[' . tep_output_string($name) . ']';
	if (empty($value) && isset($GLOBALS[$fieldName])) $value = stripslashes($GLOBALS[$fieldName]);
	
	$langs = empty($value) ? array() : explode(';', $value);
	
	$field = '<select name="' . tep_output_string($name) . '" multiple="multiple" onChange="JavaScript:payzenProcessLangs()">';
	foreach ($payzen_supported_languages as $key => $label) {
		$field .= '<option value="' . $key . '"';
		if (in_array($key, $langs)) {
			$field .= ' selected="selected"';
		}
	
		$field .= '>' . tep_output_string(payzen_get_lang_title($key)) . '</option>';
	}
	$field .= '</select> <br />';
	
	$field .= <<<JSCODE
	<script>
		function payzenProcessLangs() {
			var elt = document.forms['modules'].elements['$name'];
	
			var result = '';
			for (var i=0; i < elt.length; i++) {
            	if(elt[i].selected) {
            		if(result != '') result += ';';
            	
             		result += elt[i].value;
            	}
         	}
	
         	document.forms['modules'].elements['$fieldName'].value = result;
		}
	</script>
JSCODE;
	
	$field .= '<input type="hidden" name="' . tep_output_string($fieldName) . '" value="' . $value . '">';
	
	return $field;
}

function payzen_cfg_draw_pull_down_cards($value='', $name) {
	global $payzen_supported_cards;

	$fieldName = 'configuration[' . tep_output_string($name) . ']';
	if (empty($value) && isset($GLOBALS[$fieldName])) $value = stripslashes($GLOBALS[$fieldName]);

	$cards = empty($value) ? array() : explode(';', $value);

	$field = '<select name="' . tep_output_string($name) . '" multiple="multiple" onChange="JavaScript:payzenProcessCards()">';
	foreach ($payzen_supported_cards as $key => $label) {
		$field .= '<option value="' . $key . '"';
		if (in_array($key, $cards)) {
			$field .= ' selected="selected"';
		}

		$field .= '>' . tep_output_string($label) . '</option>';
	}
	$field .= '</select> <br />';

	$field .= <<<JSCODE
	<script>
		function payzenProcessCards() {
			var elt = document.forms['modules'].elements['$name'];

			var result = '';
			for (var i=0; i < elt.length; i++) {
            	if(elt[i].selected) {
            		if(result != '') result += ';';
       
             		result += elt[i].value;
            	}
         	}

         	document.forms['modules'].elements['$fieldName'].value = result;
		}
	</script>
JSCODE;

	$field .= '<input type="hidden" name="' . tep_output_string($fieldName) . '" value="' . $value . '">';

	return $field;
}
?>